@@ -9,5 +9,5 @@ from .uk_who import select_reference_data_for_uk_who_chart
 from .turner import select_reference_data_for_turner
 from .trisomy_21 import select_reference_data_for_trisomy_21
 from .measurement import Measurement
-from .chart_functions import create_chart, create_plottable_child_data, generate_custom_centile, generate_custom_sds_line
+from .chart_functions import create_chart, generate_custom_sds_line
 from .constants import *
