@@ -107,6 +107,8 @@ class Measurement:
                 "x": self.ages_object['measurement_dates']['chronological_decimal_age'],
                 "y": self.observation_value,
                 "b": self.bone_age,
+                "centile": self.calculated_measurements_object["measurement_calculated_values"]["chronological_centile"],
+                "sds": self.calculated_measurements_object["measurement_calculated_values"]["chronological_sds"],
                 "events_text": self.events_text,
                 "bone_age_label": self.bone_age_text,
                 "bone_age_type": self.bone_age_type,
@@ -126,6 +128,8 @@ class Measurement:
                 "x": self.ages_object['measurement_dates']['corrected_decimal_age'],
                 "y": self.observation_value,
                 "b": self.bone_age,
+                "centile": self.calculated_measurements_object["measurement_calculated_values"]["corrected_centile"],
+                "sds": self.calculated_measurements_object["measurement_calculated_values"]["corrected_sds"],
                 "events_text": self.events_text,
                 "bone_age_label": self.bone_age_text,
                 "bone_age_type": self.bone_age_type,
@@ -148,6 +152,7 @@ class Measurement:
                 "x": self.ages_object['measurement_dates']['chronological_decimal_age'],
                 "y": self.calculated_measurements_object['measurement_calculated_values']["chronological_sds"],
                 "b": self.bone_age,
+                "centile": self.calculated_measurements_object["measurement_calculated_values"]["chronological_centile"],
                 "events_text": self.events_text,
                 "bone_age_label": self.bone_age_text,
                 "bone_age_type": self.bone_age_type,
@@ -165,6 +170,7 @@ class Measurement:
                 "x": self.ages_object['measurement_dates']['corrected_decimal_age'],
                 "y": self.calculated_measurements_object['measurement_calculated_values']["corrected_sds"],
                 "b": self.bone_age,
+                "centile": self.calculated_measurements_object["measurement_calculated_values"]["corrected_centile"],
                 "events_text": self.events_text,
                 "bone_age_label": self.bone_age_text,
                 "bone_age_type": self.bone_age_type,
